@@ -77,8 +77,8 @@ class Actor:
             "namespace": "",
         },
     )
-    pose: "Actor.Pose" = field(
-        default="0 0 0 0 0 0",
+    pose: Optional["Actor.Pose"] = field(
+        default=None,
         metadata={
             "type": "Element",
             "namespace": "",
@@ -334,8 +334,8 @@ class Actor:
             defined inside the parent that this frame is attached to.
         """
 
-        pose: "Actor.Frame.Pose" = field(
-            default="0 0 0 0 0 0",
+        pose: Optional["Actor.Frame.Pose"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -360,7 +360,7 @@ class Actor:
             """
 
             value: str = field(
-                default="",
+                default="0 0 0 0 0 0",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -383,7 +383,7 @@ class Actor:
         """
 
         value: str = field(
-            default="",
+            default="0 0 0 0 0 0",
             metadata={
                 "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
