@@ -77,8 +77,8 @@ class Visual:
             "namespace": "",
         },
     )
-    pose: "Visual.Pose" = field(
-        default="0 0 0 0 0 0",
+    pose: Optional["Visual.Pose"] = field(
+        default=None,
         metadata={
             "type": "Element",
             "namespace": "",
@@ -149,7 +149,7 @@ class Visual:
         """
 
         value: str = field(
-            default="",
+            default="0 0 0 0 0 0",
             metadata={
                 "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
